extern const char **_dictionary_inittab;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_inittab;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_inittab("inittab",_dictionary_inittab,8,0);\
	void dummy_dict_inittab(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_inittab[id]
	#define MSG_B(id,m,n)	_dictionary_inittab[id]
	#define MSG_R(id)	_dictionary_inittab[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_inittab,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_inittab,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_inittab,id)
#endif
#define M_inittab	0
#define T_USAGE	1
#define F_DEFAULTLEVEL	2
#define T_DEFLEVEL	3
#define F_RUNLEVEL	4
#define I_TEXTMODE	5
#define I_GRAPHICMODE	6
#define I_SINGLEMODE	7
